# dicthandling

`dicthandling` is a python module containing convenient methods handling python
dictionaries. [Read-the-docs](https://dicthandling.readthedocs.io/en/latest/) for
a detailed description of its methods.

## Installing

Installing the latest release using pip is recommended.

````shell script
$ pip install dicthandling
````

The latest development state can be obtained from gitlab using pip.

````shell script
$ pip install git+https://gitlab.com/david.scheliga/dicthandling.git@dev
````

## Authors

* **David Scheliga** 
    [@gitlab](https://gitlab.com/david.scheliga)
    [@Linkedin](https://www.linkedin.com/in/david-scheliga-576984171/)
    - Initial work
    - Maintainer

## License

This project is licensed under the GNU GENERAL PUBLIC LICENSE - see the
[LICENSE](https://gitlab.com/david.scheliga/dicthandling/blob/master/LICENSE) file for details

## Acknowledge

- [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
- [PurpleBooth](https://gist.github.com/PurpleBooth/109311bb0361f32d87a2)
- [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)